A function for saving the results of a ChASM analysis as a tsv
saveChASM.RdA function for saving the results of a ChASM analysis as a tsv
Examples
example_calls <- runChASM(rawReadCountsIn = example_data)
if (FALSE) { # \dontrun{
saveChASM(inChASM = example_calls)
} # }